This S3 method converts an adjacency key object (typically a 2-row matrix or list of pairs) into a character vector, concatenating each pair with ' & '.
# S3 method for adjacency.key
as.character(x, ...)A character vector where each element is a concatenation of the adjacency key pair.
An adjacency key object (matrix or list) to convert to character.
Additional arguments (unused).