Learn R Programming

tma (version 0.3.1)

as.matrix.network.connections: Convert Network Connections to Matrix (S3 method)

Description

This S3 method extracts the connection columns from a network connections object and returns them as a numeric matrix. It is used to facilitate matrix operations on network connection data.

Usage

# S3 method for network.connections
as.matrix(x, ...)

Value

A numeric matrix of network connections (rows = units/contexts, columns = connections).

Arguments

x

An object of class "network.connections" (or compatible data.table/data.frame) containing connection columns (of class "network.connection").

...

Additional arguments passed to `as.matrix`.