Learn R Programming

tma (version 0.3.1)

as.unordered.ordered.ena.connections: Unorder Connections in a Matrix

Description

This function takes a matrix and creates an unordered version of its connections, combining upper and lower triangular elements.

Usage

# S3 method for ordered.ena.connections
as.unordered(x)

Value

A data.table with ordered connections, reclassified as "unordered.ena.connections", "ena.connections", and "ena.matrix".

Arguments

x

A matrix or data frame containing the connections. The input should be a square matrix.