Learn R Programming

tma (version 0.3.1)

as.unordered.ordered.row.connections: Convert Ordered Row Connections to Unordered (S3 method)

Description

This S3 method takes a matrix or data frame of ordered row connections (e.g., from ONA) and produces an unordered version by summing upper and lower triangular elements for each connection.

Usage

# S3 method for ordered.row.connections
as.unordered(x)

Value

A data.table with unordered row connections, reclassified as "unordered.row.connections", "row.connections", and "ena.matrix".

Arguments

x

An object of class "ordered.row.connections" (or compatible matrix/data.frame) containing ordered connection data. The input should be a square matrix or have square number of columns.