This S3 method extracts the connection columns from a network connections object and returns them as a numeric matrix. It is used to facilitate matrix operations on network connection data.
# S3 method for network.connections
as.matrix(x, ...)A numeric matrix of network connections (rows = units/contexts, columns = connections).
An object of class "network.connections" (or compatible data.table/data.frame) containing connection columns (of class "network.connection").
Additional arguments passed to `as.matrix`.