This function takes a matrix and creates an unordered version of its connections, combining upper and lower triangular elements.
# S3 method for ordered.ena.connections
as.unordered(x)A data.table with ordered connections, reclassified as "unordered.ena.connections", "ena.connections", and "ena.matrix".
A matrix or data frame containing the connections. The input should be a square matrix.