This S3 method takes a matrix or data frame of ordered row connections (e.g., from ONA) and produces an unordered version by summing upper and lower triangular elements for each connection.
# S3 method for ordered.row.connections
as.unordered(x)A data.table with unordered row connections, reclassified as "unordered.row.connections", "row.connections", and "ena.matrix".
An object of class "ordered.row.connections" (or compatible matrix/data.frame) containing ordered connection data. The input should be a square matrix or have square number of columns.